@@ -98,12 +98,19 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, Partitio
                         }
                         setupOptions(currentEntry->options());
                       });
+    connect(m_EditPath, &QComboBox::currentTextChanged, this, &EditMountPointDialogWidget::currentPathChanged);
+    currentPathChanged(m_EditPath->currentText());
 }
 
 EditMountPointDialogWidget::~EditMountPointDialogWidget()
 {
 }
 
+bool EditMountPointDialogWidget::isValid() const
+{
+    return m_valid;
+}
+
 void EditMountPointDialogWidget::setupOptions(const QStringList& options)
 {
     QStringList optTmpList;
@@ -152,6 +159,8 @@ void EditMountPointDialogWidget::setupRadio(const FstabEntry::Type entryType)
         break;
     case FstabEntry::Type::comment:
         break;
+    default:
+        break;
     }
 }
 
@@ -222,3 +231,16 @@ void EditMountPointDialogWidget::acceptChanges()
     else
         currentEntry->setFsSpec(m_deviceNode);
 }
+
+void EditMountPointDialogWidget::currentPathChanged(const QString &newPath)
+{
+    auto path = newPath.trimmed().toLower();
+    if (path.isEmpty() || path == QStringLiteral("none")) {
+        m_valid = false;
+        m_PathMessage->setVisible(true);
+    } else {
+        m_valid = true;
+        m_PathMessage->setVisible(false);
+    }
+    Q_EMIT isValidChanged(m_valid);
+}
